==> kblogger_0.5.orig.tar.gz: kblogger-0.5/src/kbloggerconfigdialog.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Christian Weilbach   *
 *   christian_weilbach@web.de   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef KBLOGGERCONFIGDIALOG_H
#define KBLOGGERCONFIGDIALOG_H

#include "kbloggerconfigblank.h"
#include "API_Blogger.h"

class KBloggerConfigDialog : public KBloggerConfigBlank
{
	Q_OBJECT
	
public:
	KBloggerConfigDialog(QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
	~KBloggerConfigDialog();
	/*$PUBLIC_FUNCTIONS$*/
	
public slots:
	/*$PUBLIC_SLOTS$*/
 	void fetchSlot(QString, QString);
	
protected:
	/*$PROTECTED_FUNCTIONS$*/
	
protected slots:
	/*$PROTECTED_SLOTS$*/
	
};

#endif

==> kblogger_0.6.5.orig.tar.gz: kblogger-0.6.5/src/kbloggerconfigdialog.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Christian Weilbach   *
 *   christian_weilbach@web.de   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef KBLOGGERCONFIGDIALOG_H
#define KBLOGGERCONFIGDIALOG_H

#include "kbloggerconfigblank.h"
#include <qvaluevector.h>
#include "API_Blog.h"

class KBloggerConfigDialog : public KBloggerConfigBlank
{
	Q_OBJECT
	
public:
	KBloggerConfigDialog(QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
	~KBloggerConfigDialog();
	/*$PUBLIC_FUNCTIONS$*/
	
public slots:
	/*$PUBLIC_SLOTS$*/

	
protected:
	/*$PROTECTED_FUNCTIONS$*/
	
private slots:
	/*$PROTECTED_SLOTS$*/
	void updateBlogIds();
	void addBlogId( const QString&, const QString& );
	void setUrl( int );
	void setBlogName( int );
private:
	KBlog::APIBlog *backend;
	QValueVector<QString> blogNames;
};

#endif
